@@ -35,7 +35,7 @@ public:
     ~ThemeEditorMainWindow();
 
 protected:
-    void closeEvent(QCloseEvent *) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *) override;
 
 private Q_SLOTS:
     void slotNewTheme();
